"use client";
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var navigation = require('next/navigation');
var React = require('react');
var useLocale = require('../../react-client/useLocale.js');
var utils = require('../../shared/utils.js');

/**
 * Returns the pathname without a potential locale prefix.
 *
 * @example
 * ```tsx
 * 'use client';
 *
 * import {usePathname} from 'next-intl/client';
 *
 * // When the user is on `/en`, this will be `/`
 * const pathname = usePathname();
 * ```
 */
function useBasePathname(localePrefix) {
  // The types aren't entirely correct here. Outside of Next.js
  // `useParams` can be called, but the return type is `null`.

  // Notes on `useNextPathname`:
  // - Types aren't entirely correct. Outside of Next.js the
  //   hook will return `null` (e.g. unit tests)
  // - A base path is stripped from the result
  // - Rewrites *are* taken into account (i.e. the pathname
  //   that the user sees in the browser is returned)
  const pathname = navigation.usePathname();
  const locale = useLocale.default();
  return React.useMemo(() => {
    if (!pathname) return pathname;
    const prefix = utils.getLocalePrefix(locale, localePrefix);
    const isPathnamePrefixed = utils.hasPathnamePrefixed(prefix, pathname);
    const unlocalizedPathname = isPathnamePrefixed ? utils.unprefixPathname(pathname, prefix) : pathname;
    return unlocalizedPathname;
  }, [locale, localePrefix, pathname]);
}

exports.default = useBasePathname;
